@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-KM3NeT Data Definitions v1.1.2
+KM3NeT Data Definitions v1.2.2
 https://git.km3net.de/common/km3net-dataformat
 """
 
@@ -22,16 +22,21 @@ data = {
     "JSHOWERPOSITIONFIT": 102,
     "JSHOWERCOMPLETEFIT": 103,
     "JSHOWER_BJORKEN_Y": 104,
+    "JSHOWERENERGYPREFIT": 105,
+    "JSHOWERPOINTSIMPLEX": 106,
+    "JSHOWERDIRECTIONPREFIT": 107,
     "JSHOWEREND": 199,
-    "DUSJSHOWERFIT": 200,
-    "DUSJBEGIN": 200,
-    "DUSJPREFIT": 201,
-    "DUSJPOSITIONFIT": 202,
-    "JDUSJCOMPLETEFIT": 203,
-    "DUSJEND": 299,
-    "AASHOWERFIT": 300,
+    "DUSJ_RECONSTRUCTION_TYPE": 200,
+    "DUSJSHOWERBEGIN": 200,
+    "DUSJSHOWERPREFIT": 201,
+    "DUSJSHOWERPOSITIONFIT": 202,
+    "DUSJSHOWERCOMPLETEFIT": 203,
+    "DUSJSHOWERBEND": 299,
+    "AANET_RECONSTRUCTION_TYPE": 101,
     "AASHOWERBEGIN": 300,
-    "AASHOWERCOMPLETEFIT": 301,
+    "AASHOWERFITPREFIT": 302,
+    "AASHOWERFITPOSITIONFIT": 303,
+    "AASHOWERFITDIRECTIONENERGYFIT": 304,
     "AASHOWEREND": 399,
     "JUSERBEGIN": 1000,
     "JMUONVETO": 1001,
