@@ -143,8 +143,7 @@ class Branch:
                 self._branch[self._keymap[key]]._context, 6)
 
         out = self._branch[self._keymap[key]].lazyarray(
-            interpretation=interpretation,
-            basketcache=BASKET_CACHE)
+            interpretation=interpretation, basketcache=BASKET_CACHE)
         if self._index_chain is not None and key in self._mapper.toawkward:
             cache_key = self._mapper.name + '/' + key
             if cache_key not in self._awkward_cache:
@@ -159,8 +158,11 @@ class Branch:
         if isinstance(item, str):
             return self.__getkey__(item)
 
-        if item.__class__.__name__ == "ChunkedArray":
-            item = np.array(item)
+        if isinstance(item, (np.int32, np.int64)):
+            item = int(item)
+
+        # if item.__class__.__name__ == "ChunkedArray":
+        #     item = np.array(item)
 
         return self.__class__(self._tree,
                               self._mapper,
@@ -172,7 +174,7 @@ class Branch:
     def __len__(self):
         if not self._index_chain:
             return len(self._branch)
-        elif isinstance(self._index_chain[-1], int):
+        elif isinstance(self._index_chain[-1], (int, np.int32, np.int64)):
             return 1
         else:
             return len(
