@@ -1,75 +1,20 @@
 import unittest
 import numpy as np
-import awkward1 as ak1
 from pathlib import Path
 
+from km3net_testdata import data_path
+
 from km3io import OfflineReader
-from km3io.offline import _nested_mapper, Header, fitinf, fitparams, count_nested, _find, mask
+from km3io.offline import _nested_mapper, Header
 
-SAMPLES_DIR = Path(__file__).parent / 'samples'
-OFFLINE_FILE = OfflineReader(SAMPLES_DIR / 'aanet_v2.0.0.root')
-OFFLINE_USR = OfflineReader(SAMPLES_DIR / 'usr-sample.root')
-OFFLINE_MC_TRACK_USR = OfflineReader(SAMPLES_DIR / 'mcv5.11r2.gsg_muonCChigherE-CC_50-5000GeV.km3_AAv1.jterbr00004695.jchain.aanet.498.root')
-OFFLINE_NUMUCC = OfflineReader(SAMPLES_DIR / "numucc.root")  # with mc data
-
-
-class TestFitinf(unittest.TestCase):
-    def setUp(self):
-        self.tracks = OFFLINE_FILE.events.tracks
-        self.fit = self.tracks.fitinf
-        self.best = self.tracks[:, 0]
-        self.best_fit = self.best.fitinf
-
-    def test_fitinf(self):
-        beta = fitinf('JGANDALF_BETA0_RAD', self.tracks)
-        best_beta = fitinf('JGANDALF_BETA0_RAD', self.best)
-
-        assert beta[0][0] == self.fit[0][0][0]
-        assert beta[0][1] == self.fit[0][1][0]
-        assert beta[0][2] == self.fit[0][2][0]
-
-        assert best_beta[0] == self.best_fit[0][0]
-        assert best_beta[1] == self.best_fit[1][0]
-        assert best_beta[2] == self.best_fit[2][0]
-
-    def test_fitparams(self):
-        keys = set(fitparams())
-
-        assert "JGANDALF_BETA0_RAD" in keys
-
-
-class TestCountNested(unittest.TestCase):
-    def test_count_nested(self):
-        fit = OFFLINE_FILE.events.tracks.fitinf
-
-        assert count_nested(fit, axis=0) == 10
-        assert count_nested(fit, axis=1)[0:4] == ak1.Array([56, 55, 56, 56])
-        assert count_nested(fit, axis=2)[0][0:4] == ak1.Array([17, 11, 8, 8])
-
-
-class TestRecStagesMasks(unittest.TestCase):
-    def setUp(self):
-        self.nested = ak1.Array([[[1, 2, 3], [1, 2, 3], [1]], [[0], [1, 2, 3]],
-                                 [[0], [0, 1, 3], [0], [1, 2, 3], [1, 2, 3]]])
-
-    def test_find(self):
-        builder = ak1.ArrayBuilder()
-        _find(self.nested, ak1.Array([1, 2, 3]), builder)
-        labels = builder.snapshot()
-
-        assert labels[0][0] == 1
-        assert labels[0][1] == 1
-        assert labels[0][2] == 0
-        assert labels[1][0] == 0
-
-    def test_mask(self):
-        rec_stages = OFFLINE_FILE.events.tracks.rec_stages
-        stages = [1, 3, 5, 4]
-        masks = mask(rec_stages, stages)
-
-        assert masks[0][0] == all(rec_stages[0][0] == ak1.Array(stages))
-        assert masks[1][0] == all(rec_stages[1][0] == ak1.Array(stages))
-        assert masks[0][1] == False
+OFFLINE_FILE = OfflineReader(data_path("offline/km3net_offline.root"))
+OFFLINE_USR = OfflineReader(data_path("offline/usr-sample.root"))
+OFFLINE_MC_TRACK_USR = OfflineReader(
+    data_path(
+        'offline/mcv5.11r2.gsg_muonCChigherE-CC_50-5000GeV.km3_AAv1.jterbr00004695.jchain.aanet.498.root'
+    ))
+OFFLINE_NUMUCC = OfflineReader(
+    data_path("offline/numucc.root"))  # with mc data
 
 
 class TestOfflineReader(unittest.TestCase):
@@ -79,9 +24,9 @@ class TestOfflineReader(unittest.TestCase):
         self.n_events = 10
 
     def test_context_manager(self):
-        filename = SAMPLES_DIR / 'aanet_v2.0.0.root'
-        with OfflineReader(filename) as r:
-            assert r._filename == filename
+        filename = OFFLINE_FILE
+        with OfflineReader(data_path("offline/km3net_offline.root")) as r:
+            assert r
 
     def test_number_events(self):
         assert self.n_events == len(self.r.events)
@@ -442,10 +387,12 @@ class TestMcTrackUsr(unittest.TestCase):
     def test_usr_names(self):
         n_tracks = len(self.f.events)
         for i in range(3):
-            self.assertListEqual([b'bx', b'by', b'ichan', b'cc'],
-                                self.f.events.mc_tracks.usr_names[i][0].tolist())
-            self.assertListEqual([b'energy_lost_in_can'],
-                                self.f.events.mc_tracks.usr_names[i][1].tolist())
+            self.assertListEqual(
+                [b'bx', b'by', b'ichan', b'cc'],
+                self.f.events.mc_tracks.usr_names[i][0].tolist())
+            self.assertListEqual(
+                [b'energy_lost_in_can'],
+                self.f.events.mc_tracks.usr_names[i][1].tolist())
 
     def test_usr(self):
         assert np.allclose([0.0487, 0.0588, 3, 2],
